(function() {
    "use strict";

    angular.module("weChatApp")
        .factory("ConsentService", ["$q", "Endpoints", ConsentService])
    ;

    function ConsentService($q, endpoints) {
        var service = this;

        service.getWeChatConsentByAccounts = function(accounts, filterDates) {
            var deferred = $q.defer();
            var accountIds = [];
            var accountIdToNameMap = {};

            accounts.forEach(function(account) {
                accountIds.push(account.Id);
                accountIdToNameMap[account.Id] = account.Name;
            });

            endpoints.fetchMultichannelConsentByAccountIds(accountIds, filterDates.startDatetime, filterDates.endDatetime).then(function(rawResp) {
                var consentResp = rawResp.Multichannel_Consent_vod__c;

                // fetch recordtype id for wechat_vod
                endpoints.fetchWeChatRecordType().then(function(recordTypeResp) {
                    var weChatRecordTypeId = recordTypeResp.RecordType[0] ? recordTypeResp.RecordType[0].Id : null;

                    // filter mc consent by record type id to get WeChat consent only
                    var weChatConsentResp = consentResp.filter(function(consentData) {
                        return consentData.RecordTypeId === weChatRecordTypeId;
                    });

                    weChatConsentResp.forEach(function(consent) {
                        if(!!consent.Account_vod__c) {
                            consent.accountName = accountIdToNameMap[consent.Account_vod__c];
                        }
                    });
                    deferred.resolve(weChatConsentResp);
                }, deferred.reject);
            }, deferred.reject);
            return deferred.promise;
        };

        return service;
    }
}());